==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/certificateregistration/kotlin/inputs/AppServiceCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.certificateregistration.kotlin.inputs

import com.pulumi.azurenative.certificateregistration.inputs.AppServiceCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Key Vault container for a certificate that is purchased through Azure.
 * @property keyVaultId Key Vault resource Id.
 * @property keyVaultSecretName Key Vault secret name.
 */
public data class AppServiceCertificateArgs(
    public val keyVaultId: Output<String>? = null,
    public val keyVaultSecretName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.certificateregistration.inputs.AppServiceCertificateArgs> {
    override fun toJava():
        com.pulumi.azurenative.certificateregistration.inputs.AppServiceCertificateArgs =
        com.pulumi.azurenative.certificateregistration.inputs.AppServiceCertificateArgs.builder()
            .keyVaultId(keyVaultId?.applyValue({ args0 -> args0 }))
            .keyVaultSecretName(keyVaultSecretName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AppServiceCertificateArgs].
 */
@PulumiTagMarker
public class AppServiceCertificateArgsBuilder internal constructor() {
    private var keyVaultId: Output<String>? = null

    private var keyVaultSecretName: Output<String>? = null

    /**
     * @param value Key Vault resource Id.
     */
    @JvmName("ttytmctjrgocduis")
    public suspend fun keyVaultId(`value`: Output<String>) {
        this.keyVaultId = value
    }

    /**
     * @param value Key Vault secret name.
     */
    @JvmName("dbrqajmyfkhlnjrw")
    public suspend fun keyVaultSecretName(`value`: Output<String>) {
        this.keyVaultSecretName = value
    }

    /**
     * @param value Key Vault resource Id.
     */
    @JvmName("shxjexkedvlxttlk")
    public suspend fun keyVaultId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultId = mapped
    }

    /**
     * @param value Key Vault secret name.
     */
    @JvmName("yjnxcdujlnwqdies")
    public suspend fun keyVaultSecretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultSecretName = mapped
    }

    internal fun build(): AppServiceCertificateArgs = AppServiceCertificateArgs(
        keyVaultId = keyVaultId,
        keyVaultSecretName = keyVaultSecretName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/certificateregistration/kotlin/inputs/AppServiceCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.certificateregistration.kotlin.inputs

import com.pulumi.azurenative.certificateregistration.inputs.AppServiceCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Key Vault container for a certificate that is purchased through Azure.
 * @property keyVaultId Key Vault resource Id.
 * @property keyVaultSecretName Key Vault secret name.
 */
public data class AppServiceCertificateArgs(
    public val keyVaultId: Output<String>? = null,
    public val keyVaultSecretName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.certificateregistration.inputs.AppServiceCertificateArgs> {
    override fun toJava():
        com.pulumi.azurenative.certificateregistration.inputs.AppServiceCertificateArgs =
        com.pulumi.azurenative.certificateregistration.inputs.AppServiceCertificateArgs.builder()
            .keyVaultId(keyVaultId?.applyValue({ args0 -> args0 }))
            .keyVaultSecretName(keyVaultSecretName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AppServiceCertificateArgs].
 */
@PulumiTagMarker
public class AppServiceCertificateArgsBuilder internal constructor() {
    private var keyVaultId: Output<String>? = null

    private var keyVaultSecretName: Output<String>? = null

    /**
     * @param value Key Vault resource Id.
     */
    @JvmName("lwnmjskucdjgkbfv")
    public suspend fun keyVaultId(`value`: Output<String>) {
        this.keyVaultId = value
    }

    /**
     * @param value Key Vault secret name.
     */
    @JvmName("gtclbsnccbiuiynf")
    public suspend fun keyVaultSecretName(`value`: Output<String>) {
        this.keyVaultSecretName = value
    }

    /**
     * @param value Key Vault resource Id.
     */
    @JvmName("fkbivtfhoqrgccca")
    public suspend fun keyVaultId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultId = mapped
    }

    /**
     * @param value Key Vault secret name.
     */
    @JvmName("fbhcyvlggcsurdct")
    public suspend fun keyVaultSecretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultSecretName = mapped
    }

    internal fun build(): AppServiceCertificateArgs = AppServiceCertificateArgs(
        keyVaultId = keyVaultId,
        keyVaultSecretName = keyVaultSecretName,
    )
}
